@@ -1,7 +1,7 @@
 import os
 import requests
 
-API_URL = os.getenv('CRONO_API_URL', 'https://api.crono.com')
+API_URL = os.getenv('CRONO_API_URL')
 API_KEY = os.getenv('CRONO_API_KEY')
 API_KEY_HEADER = 'X-API-Key'
 
@@ -11,15 +11,19 @@ class Job:
 		self.headers = {API_KEY_HEADER: API_KEY}
 		self.trigger = trigger
 		self.task = task
-		self.uuid = None
+		self.sent = False
 
 	def send(self):
 
-		if self.uuid == None and self.task != None and self.trigger != None:
+		if self.sent == False and self.task != None and self.trigger != None:
 			url = f'{API_URL}/jobs'
 			json = {'task': self.task, 'trigger': self.trigger}
 			response = requests.post(url, headers=self.headers, json=json)
-			self.uuid = response.json()
+
+			if response.status_code != requests.codes.ok:
+				return False
+
+			self.sent = True
 			return response.json()
 		
 		return self
@@ -31,6 +35,10 @@ class Job:
 		url = f'{API_URL}/jobs'
 		headers = {API_KEY_HEADER: API_KEY} # TODO cls.headers?
 		response = requests.get(url, headers=headers)
+
+		if response.status_code != requests.codes.ok:
+			return False
+		
 		return response.json()
 
 	@classmethod
@@ -38,17 +46,41 @@ class Job:
 		url = f'{API_URL}/jobs/{uuid}'
 		headers = {API_KEY_HEADER: API_KEY} # TODO cls.headers?
 		response = requests.get(url, headers=headers)
-		response.raise_for_status() # r.status_code == requests.codes.ok
-		return response.json()
+		
+		if response.status_code != requests.codes.ok:
+			return False
+
+		return response.json()		
 
 	@classmethod
 	def delete(cls, uuid):
 		url = f'{API_URL}/jobs/{uuid}'
 		headers = {API_KEY_HEADER: API_KEY} # TODO cls.headers?
 		response = requests.delete(url, headers=headers)
-		response.raise_for_status() # r.status_code == requests.codes.ok
+
+		if response.status_code != requests.codes.ok
+			return False
+		
 		return response.json()
 
+	# Tasks
+
+	def log(self, *args, **kwargs):
+		self.task = {'name': 'log', 'args': args, 'kwargs': kwargs}
+		return self.send()
+
+	def request(self, *args, **kwargs):
+		self.task = {'name': 'request', 'args': args, 'kwargs': kwargs}
+		return self.send()
+
+	def message(self, *args, **kwargs):
+		self.tas = {'name': 'message', 'args': args, 'kwargs': kwargs}
+		return self.send()
+
+	def email(self, *args, **kwargs):
+		self.task = {'name': 'email', 'args': args, 'kwargs': kwargs}
+		return self.send()
+
 	# Triggers
 
 	def on(self, *args, **kwargs):
@@ -70,21 +102,3 @@ class Job:
 	def at(self, *args, **kwargs):
 		self.trigger = {'name': 'at', 'args': args, 'kwargs': kwargs}
 		return self.send()
-
-	# Tasks
-
-	def log(self, *args, **kwargs):
-		self.task = {'name': 'log', 'args': args, 'kwargs': kwargs}
-		return self.send()
-
-	def request(self, *args, **kwargs):
-		self.task = {'name': 'request', 'args': args, 'kwargs': kwargs}
-		return self.send()
-
-	def message(self, *args, **kwargs):
-		self.tas = {'name': 'message', 'args': args, 'kwargs': kwargs}
-		return self.send()
-
-	def email(self, *args, **kwargs):
-		self.task = {'name': 'email', 'args': args, 'kwargs': kwargs}
-		return self.send()
